# -*- coding: utf-8 -*-
'''
@File  : osspath.py
@Author: Jike Data Analysis Modeling Group
@Date  : 2021/12/4 12:13 上午
@Desc  : oss数据存储路径
'''

_M_CROWD_PACK_RESULT_PATH = 'oss://geek-results/jklwcs/results/m_crowd_pack/'
_M_CROWD_PACK_TEMP_PATH = 'oss://geek-results/jklwcs/temp/m_crowd_pack/'
_M_ARRIVED_DETAILS_RESULT_PATH = 'oss://geek-results/jklwcs/results/m_arrived_details/'
_M_ARRIVED_DETAILS_TEMP_PATH = 'oss://geek-results/jklwcs/temp/m_arrived_details/'
